%% smoking probability maps

%% Set Up Data

clear; clc;

work = csvread('workmap1.csv',0,0);
work(:, 3) = csvread('workmap2.csv', 1, 1);
work(:, 4) = csvread('workmap3.csv', 1, 1);

rest(:, 1:2) = csvread('restmap1.csv', 1, 0);
rest(:, 3) = csvread('restmap2.csv', 1, 1);
rest(:, 4) = csvread('restmap3.csv', 1, 1);

bar(:, 1:2) = csvread('barmap1.csv', 1, 0);
bar(:, 3) = csvread('barmap2.csv', 1, 1);
bar(:, 4) = csvread('barmap3.csv', 1, 1);


mData(:, :, 1) = map_data(work);
mData(:, :, 2) = map_data(bar);
mData(:, :, 3) = map_data(rest);

data{1, 1} = 'WorkBans';
data{2, 1} = 'BarBans';
data{3, 1} = 'RestaurantBans';

date{1, 1} = '2001:Q1';
date{2, 1} = '2005:Q2';
date{3, 1} = '2009:Q4';

nCounties = size(mData, 1);
nGraphs = size(mData,2)-1; 
mycolors = [0 0 0;  0 0 205;  0 43 229; 47 113 235; 98 170 241; 150 215 247; 206 245 253]/255;
%labels = {'P = 0.0', '0.2 > P > 0.0', '0.4 > P >= 0.2', '0.6 > P >= 0.4', '0.8 > P >= 0.6', '1.0 > P >= 0.8', 'P = 1.0'};
%labels = {'0', '<0.2', '<0.4', '<0.6', '<0.8', '<1.0', '1.0'};
labels = {'', '', '', '', '', '', ''};


counties_sorted = county_data(nCounties);
 
%Indexing for Hawaii, Alaska, and Conus

indexHawaii = floor(work(:, 1)/1000) == 15;
indexAlaska = floor(work(:, 1)/1000) == 2;
indexConus = 1:numel(counties_sorted);
indexConus(indexHawaii)=[];
indexConus(indexAlaska)=[];


%% Making Maps

for d = 1:nGraphs
    for qtr=1:3
        figure;
        ax = usamap('allequal');
        set(ax, 'Visible', 'off');
   
        for k = 1:nCounties
            counties_sorted(k,1).Prob = mData(k, qtr+1, d);
        end

        surfaceColors = makesymbolspec('Polygon', {'Prob', [0 6], 'FaceColor', mycolors});

        geoshow(ax(1), counties_sorted(indexConus),  'DisplayType', 'polygon', 'SymbolSpec', surfaceColors);
        geoshow(ax(2), counties_sorted(indexAlaska),  'DisplayType', 'polygon', 'SymbolSpec', surfaceColors);
        geoshow(ax(3), counties_sorted(indexHawaii),  'DisplayType', 'polygon', 'SymbolSpec', surfaceColors);
        setm(ax(1), 'Frame', 'off', 'Grid', 'off','MeridianLabel', 'off', 'ParallelLabel', 'off');
        setm(ax(2), 'Frame', 'off', 'Grid', 'off','MeridianLabel', 'off', 'ParallelLabel', 'off');
        setm(ax(3), 'Frame', 'off', 'Grid', 'off','MeridianLabel', 'off', 'ParallelLabel', 'off');

        if qtr==3
        colormap(mycolors);
        lcolorbar(labels);
        end
        
        title([date{qtr, 1}],'FontSize',20);
        

%save_fig = horzcat('hgsave ', num2str(d),'_', num2str(qtr));
save_pdf = horzcat('print ( ''-dpdf'', ''', data{d,1}, '_', num2str(qtr), ''')');
%save_eps = horzcat('print ( ''-depsc2'', ''', data{d,1}, '_', num2str(qtr), '.eps'')');
%eval(save_fig);
eval(save_pdf);
%eval(save_eps);

close;

    end
end

