* Code for Michael T. Owyang and E. Katarina Vermann "Where There's a Smoking Ban, There's Still Fire"
* Federal Reserve Bank of St. Louis Review, July/August 2012, pp. 265-286

* Main Code *

clear
set mem 800m
set mo off

** Set working directory **
* cd "/Users/KateV/Desktop/data/bans_review"

* DATA PREPARATION: BRFSS & CONTROLS *

* The data files to set up the BRFSS & Controls data (brfss&controls_nobans.dta)
* Are in the Files & Code for BRFSS&Controls_NoBans folder
* Files to set up this data set are: metroareas.do, cbp_cbsa.do, brfss_setup.do
* Within these files, you will need to reset the working directory
* However, you will not be able to recreate the price variables because the ACCRA Cost of Living data are proprietary. If you have access to those data, then the code is available in the files to create the price variables

* DATA PREPARATION: BANS *

do bancode

* ban code & data for Figure 2 *

do mapdata

*****
use brfss&controls_nobans, clear

**merge on bans: figure out to do with areas if merge on all ban data**
sort  statecode 
merge  statecode using statebans2, _merge(merge_sb)

sort fips statecode countycode
merge fips statecode countycode using countybans_all, _merge(merge_cntybans)

drop if ID==""
drop if edate_int==. 

***RE-ESTABLISH BAN STRINGENCY ASSUMPTION

replace wcworkban_date = . if (wcworkban_date>=stateworkban_date & wcworkban_date~=.)
replace wcrestban_date = . if (wcrestban_date>=staterestban_date & wcrestban_date~=.)
replace wcbarban_date = . if (wcbarban_date>=statebarban_date & wcbarban_date~=.)

replace muniworkban_date = . if (muniworkban_date >= stateworkban_date & muniworkban_date~=.)
replace muniworkban_date = . if (muniworkban_date >= wcworkban_date & muniworkban_date~=.)
replace munibarban_date = . if (munibarban_date >= statebarban_date & munibarban_date~=.)
replace munibarban_date = . if (munibarban_date >= wcbarban_date & munibarban_date~=.)
replace munirestban_date = . if (munirestban_date >= staterestban_date & munirestban_date~=.)
replace munirestban_date = . if (munirestban_date >= wcrestban_date & munirestban_date~=.)

***REDO WITH DUMMY VARIABLES***

sort cbsa_code metrodiv_code fips
egen earliestbandate_row = rowmin(muniworkban_date munirestban_date munibarban_date wcworkban_date wcbarban_date wcrestban_date stateworkban_date staterestban_date statebarban_date)
by cbsa_code metrodiv_code: egen earliestbandate_cbsa = min(earliestbandate_row)
gen banincbsa = (earliestbandate_cbsa~=.)

sort cbsa_code metrodiv_code fips
foreach b in work bar rest {
egen earliest`b'bandate_row = rowmin(muni`b'ban_date   wc`b'ban_date   state`b'ban_date)
by cbsa_code metrodiv_code: egen earliest`b'bandate_cbsa = min(earliest`b'bandate_row)
gen `b'banincbsa = (earliest`b'bandate_cbsa~=.)
}



***WAY TO CHECK***
foreach b in work bar rest {
	gen muni`b'ban = (edate_int>=muni`b'ban_date)
	gen wc`b'ban = (edate_int>=wc`b'ban_date)
	gen state`b'ban = (edate_int>=state`b'ban_date)
	}


****MAKE BAN INDICATOR***

foreach b in workban barban restban {
gen `b'_nolag = .
replace `b'_nolag = 1 if edate_int>=muni`b'_date
replace `b'_nolag = 2 if edate_int>=wc`b'_date
replace `b'_nolag = 3 if edate_int>=state`b'_date
replace `b'_nolag = 0 if `b'_nolag==.
gen `b'_3molag = .
replace `b'_3molag = 1 if edate_int>=muni`b'_date + 91
replace `b'_3molag = 2 if edate_int>=wc`b'_date +91
replace `b'_3molag = 3 if edate_int>=state`b'_date +91
replace `b'_3molag = 0 if `b'_3molag==.

}

gen ban_any = (workban_nolag>0 | restban_nolag>0 | barban_nolag>0)

***VARIABLE FOR BAN IN CBSA****


gen urban = (cbsa_code~=.)

gen wban_any = (workban_nolag>0)
gen bban_any = (barban_nolag>0)
gen rban_any = (restban_nolag>0)

compress
save brfss_merged1, replace

***MERGE IN PROBABILITIES***

*** BAN PROBABILITIES ****
sort cbsa_code metrodiv_code edate_int
merge cbsa_code metrodiv_code edate_int using cbsawork_prob_brfssdate, _merge(mergeprob1)
sort cbsa_code metrodiv_code edate_int
merge cbsa_code metrodiv_code edate_int using cbsarest_prob_brfssdate, _merge(mergeprob2)
sort cbsa_code metrodiv_code edate_int
merge cbsa_code metrodiv_code edate_int using cbsabar_prob_brfssdate, _merge(mergeprob3)

sort fips edate_int
merge fips edate_int using cntywork_prob_brfssdate, _merge(mergeprob4)
sort fips edate_int
merge fips edate_int using cntybar_prob_brfssdate, _merge(mergeprob5)
sort fips edate_int
merge fips edate_int using cntyrest_prob_brfssdate, _merge(mergeprob6)


foreach b in work bar rest {
replace `b'probcnty = 1 if edate_int>=wc`b'ban_date
replace `b'probcnty = 1 if edate_int>=state`b'ban_date
}

save rawdata_apr2012, replace



*** setting up estimation variables ***

foreach b in work bar rest {
gen `b'prob_all = `b'probcbsa if urban==1
replace `b'prob_all = `b'probcnty if urban==0
}

*** Interaction Terms ***

*2 term

gen worklfpint_cbsa = workprob_all*lfp
gen drinkbarint_cbsa = barprob_all*drink
gen restbanint_cbsa = restprob_all

****


drop merge*

compress

merge statecode countycode fips cbsa_code metrodiv_code year using cbp_data, sort uniqusing _merge(merge_cbp)
drop if merge_cbp==2
rename indoorwork_pct_cbsa work_pct_cbsa
rename indoorwork_pct_cnty work_pct_cnty


gen worklfpint_cbsa_pct = workprob_all*work_pct_cbsa
replace worklfpint_cbsa_pct = workprob_all*work_pct_cnty if urban==0
gen drinkbarint_cbsa_pct = barprob_all*bar_pct_cbsa
replace drinkbarint_cbsa_pct = barprob_all*bar_pct_cnty if urban==0
gen  restbanint_cbsa_pct = restprob_all*rest_pct_cbsa
replace  restbanint_cbsa_pct = restprob_all*rest_pct_cnty if urban==0

foreach b in work bar rest {
rename state`b'ban state`b'ban1
gen state`b'ban = (`b'ban_3molag==3)
}

compress
* save review_data, replace

*** Table 1, Table 2,  & Figure 1 ***

gen ban_any2 = (workprob_all>0 | barprob_all>0 | restprob_all>0)



** TABLE 1**

gen white = (race_all==1)
gen age1 = (age_g6==1)
gen inc1 = (inc2==1)
gen former2 = (smoker2==0)
replace former2 = . if smokeever==0
gen quit2 = (quit==1)
gen ed1 = (education==1)

* Column 1 *
xi: sum  smokeever smoker former quit 2 smoker2 former2 quit sex white age1 i.age_g6 ed1 i.education single child drink lfp inc1 i.inc2   adjcigprice adjfundingcap_lag adjbeer *pct urban

* Column 2 *
xi: sum  smokeever smoker former quit 2 smoker2 former2 quit sex white age1 i.age_g6 ed1 i.education single child drink lfp inc1 i.inc2   adjcigprice adjfundingcap_lag adjbeer *pct urban if ban_any2==0

*Column 3*
xi: sum  smokeever smoker former quit 2 smoker2 former2 quit sex white age1 i.age_g6 ed1 i.education single child drink lfp inc1 i.inc2   adjcigprice adjfundingcap_lag adjbeer *pct urban if ban_any2==1

sum *pct*
bysort ban_any2: sum *pct *pct*


** TABLE 2 **

xi: sum i.workban_nolag i.barban_nolag i.restban_nolag *prob_all  ban_any* workbanincbsa restbanincbsa barbanincbsa
xi: sum i.workban_nolag i.barban_nolag i.restban_nolag *prob_all ban_any* workbanincbsa restbanincbsa barbanincbsa if year==2001
xi: sum i.workban_nolag i.barban_nolag i.restban_nolag *prob_all  ban_any* workbanincbsa restbanincbsa barbanincbsa if year ==2009


*** FIGURE 1 ***

bysort year: gen respondants = _N
bysort year ban_any2: gen ban_num = _N
bysort year smokeever: gen smoker_num = _N
bysort year quit: gen quit_num = _N
bysort year smoker2: gen former_num = _N

gen quit_pct = quit_num/former_num*100 if smoker2==1
gen former_pct = former_num/smoker_num*100
gen ban_pct = ban_num/respondants*100

egen quit_tag = tag(quit_pct)
egen former_tag = tag(former_pct)
egen ban_tag = tag(ban_pct)

#delimit ;

graph twoway line quit_pct year if (quit_tag==1 & quit ==0)
	|| line quit_pct year if (quit_tag==1 & quit==1)
	|| line former_pct year if (smoker2==0 & former_tag==1)
	|| line ban_pct year if (ban_tag==1 & ban_any2==1)
;
#delimit cr

graph save figure1, replace




***ESTIMATIONS***

** PROBITS: Tables 3 - 5, 7 **
* NOTE: Results in column 7 are from the controls in the column 1 specification

foreach var of varlist smokeever smoker2 quit {

* Column 1 *

qui xi: probit `var' i.workban_3molag worklfpint_cbsa i.barban_3molag drinkbarint_cbsa i.restban_3molag restbanint_cbsa ladjcigprice ladjfundinglag ladjbeer sex i.age_g6 single child i.education i.inc2 lfp drink i.race_all year i.statecode
qui testparm _Irace_all_2 - _Irace_all_8
qui local f1 = r(chi2)
qui local p1 = r(p)
qui testparm _Istatecode_4-_Istatecode_56
qui local f2 = r(chi2)
qui local p2 = r(p)
qui estat clas
outreg using `var'_probit_paper.xls, tdec(3) addstat(F-Statistic: Race, `f1', Prob > F, `p1', F-Statistic: State, `f2', Prob > F, `p2', % Correctly Predicted, r(P_corr)) replace

* Column 2 *

qui xi: probit `var'  worklfpint_cbsa  drinkbarint_cbsa  restbanint_cbsa ladjcigprice ladjfundinglag ladjbeer sex i.age_g6 single child i.education i.inc2 lfp drink i.race_all year i.statecode
qui testparm _Irace_all_2 - _Irace_all_8
qui local f1 = r(chi2)
qui local p1 = r(p)
qui testparm _Istatecode_4-_Istatecode_56
qui local f2 = r(chi2)
qui local p2 = r(p)
qui estat clas
outreg using `var'_probit_paper.xls, tdec(3) addstat(F-Statistic: Race, `f1', Prob > F, `p1', F-Statistic: State, `f2', Prob > F, `p2', % Correctly Predicted, r(P_corr)) append

* Column 3*

qui xi: probit `var' stateworkban worklfpint_cbsa statebarban drinkbarint_cbsa staterestban restbanint_cbsa ladjcigprice ladjfundinglag ladjbeer sex i.age_g6 single child i.education i.inc2 lfp drink i.race_all year i.statecode
qui testparm _Irace_all_2 - _Irace_all_8
qui local f1 = r(chi2)
qui local p1 = r(p)
qui testparm _Istatecode_4-_Istatecode_56
qui local f2 = r(chi2)
qui local p2 = r(p)
qui estat clas
outreg using `var'_probit_paper.xls, tdec(3) addstat(F-Statistic: Race, `f1', Prob > F, `p1', F-Statistic: State, `f2', Prob > F, `p2', % Correctly Predicted, r(P_corr)) append

* Column 4 *

qui xi: probit `var' i.workban_3molag  i.barban_3molag  i.restban_3molag  ladjcigprice ladjfundinglag ladjbeer sex i.age_g6 single child i.education i.inc2 lfp drink i.race_all year i.statecode
qui testparm _Irace_all_2 - _Irace_all_8
qui local f1 = r(chi2)
qui local p1 = r(p)
qui testparm _Istatecode_4-_Istatecode_56
qui local f2 = r(chi2)
qui local p2 = r(p)
qui estat clas
outreg using `var'_probit_paper.xls, tdec(3) addstat(F-Statistic: Race, `f1', Prob > F, `p1', F-Statistic: State, `f2', Prob > F, `p2', % Correctly Predicted, r(P_corr)) append

* Column 5 *

qui xi: probit `var' i.workban_3molag worklfpint_cbsa_pct i.barban_3molag drinkbarint_cbsa_pct i.restban_3molag restbanint_cbsa_pct ladjcigprice ladjfundinglag ladjbeer sex i.age_g6 single child i.education i.inc2 lfp drink i.race_all year i.statecode
qui testparm _Irace_all_2 - _Irace_all_8
qui local f1 = r(chi2)
qui local p1 = r(p)
qui testparm _Istatecode_4-_Istatecode_56
qui local f2 = r(chi2)
qui local p2 = r(p)
qui estat clas
outreg using `var'_probit_paper.xls, tdec(3) addstat(F-Statistic: Race, `f1', Prob > F, `p1', F-Statistic: State, `f2', Prob > F, `p2', % Correctly Predicted, r(P_corr)) append
}

*** MARGINAL EFFECTS ***

* Tables 6 and 8 *
* Note: The results in table 8 are from the Odd numbered columns specification *

foreach var of varlist smokeever smoker2 quit {

* Odd numbered columns *

xi: dprobit `var' i.workban_3molag  i.barban_3molag  i.restban_3molag  ladjcigprice ladjfundinglag ladjbeer sex i.age_g6 single child i.education i.inc2 lfp drink i.race_all year i.statecode
qui testparm _Irace_all_2 - _Irace_all_8
qui local f1 = r(chi2)
qui local p1 = r(p)
qui testparm _Istatecode_4-_Istatecode_56
qui local f2 = r(chi2)
qui local p2 = r(p)
qui estat clas
outreg using `var'_dprobit_paper.xls, tdec(3) addstat(F-Statistic: Race, `f1', Prob > F, `p1', F-Statistic: State, `f2', Prob > F, `p2', % Correctly Predicted, r(P_corr)) replace

* Even numbered columns *

xi: dprobit `var'  worklfpint_cbsa  drinkbarint_cbsa  restbanint_cbsa ladjcigprice ladjfundinglag ladjbeer sex i.age_g6 single child i.education i.inc2 lfp drink i.race_all year i.statecode
qui testparm _Irace_all_2 - _Irace_all_8
qui local f1 = r(chi2)
qui local p1 = r(p)
qui testparm _Istatecode_4-_Istatecode_56
qui local f2 = r(chi2)
qui local p2 = r(p)
qui estat clas
outreg using `var'_dprobit_paper.xls, tdec(3) addstat(F-Statistic: Race, `f1', Prob > F, `p1', F-Statistic: State, `f2', Prob > F, `p2', % Correctly Predicted, r(P_corr)) append
}

